Index — Rigorous Coupled Wave Analysis 1.0 documentation

# Index

C | L | M | P | S

## C

Crystal (class in rcwa)

## L

Layer (class in rcwa) | LayerStack (class in rcwa)

## M

Material (class in rcwa), [1]

## P

plotEllipsometrySpectra() (rcwa.utils.Plotter static method) plotRTEMSpectra() (rcwa.utils.Plotter static method) | plotRTSpectra() (rcwa.utils.Plotter static method) Plotter (class in rcwa.utils)

## S

Solver (class in rcwa) | Source (class in rcwa)